==> haskell-bower-json-1.1.0.0-142-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bower-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bower-json
version:              1.1.0.0
visibility:           public
id:                   bower-json-1.1.0.0-9BYJL15oJLUG9L3dZWEyqo
key:                  bower-json-1.1.0.0-9BYJL15oJLUG9L3dZWEyqo
license:              MIT
maintainer:           harry@garrood.me
author:               Harry Garrood
homepage:             https://github.com/hdgarrood/bower-json
synopsis:             Read bower.json from Haskell
description:
    Bower is a package manager for the web (see <http://bower.io>).
    This package provides a data type and ToJSON/FromJSON instances for Bower'\''s
    package manifest file, bower.json.

category:             Web
abi:                  6af617fe1e7db23364b2beffc4d3c515
exposed:              True
exposed-modules:      Web.Bower.PackageMeta
hidden-modules:       Web.Bower.PackageMeta.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/bower-json-1.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/bower-json-1.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/bower-json-1.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bower-json
hs-libraries:         HSbower-json-1.1.0.0-9BYJL15oJLUG9L3dZWEyqo
depends:
    aeson-2.1.2.1-JiLBJfeE1bfHXFEKMVOO2u
    aeson-better-errors-0.9.1.2-HEB72X6I1aM3s1tXPoO4ZQ base-4.17.2.1
    bytestring-0.11.5.3 deepseq-1.4.8.0 ghc-prim-0.9.1 mtl-2.2.2
    scientific-0.3.7.0-I6iMwi20J4G9Jw2tSdEPEK text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-7moq3V15ycBgVs1tpEAw
    vector-0.13.2.0-KDCTRjRQ0urK2B6TNAGAn8

haddock-interfaces:   /usr/share/doc/haskell-bower-json/html/bower-json.haddock
haddock-html:         /usr/share/doc/haskell-bower-json/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bower-json-1.1.0.0-143-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bower-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bower-json
version:              1.1.0.0
visibility:           public
id:                   bower-json-1.1.0.0-Jcups7R7Jws2U7K0pAgSfs
key:                  bower-json-1.1.0.0-Jcups7R7Jws2U7K0pAgSfs
license:              MIT
maintainer:           harry@garrood.me
author:               Harry Garrood
homepage:             https://github.com/hdgarrood/bower-json
synopsis:             Read bower.json from Haskell
description:
    Bower is a package manager for the web (see <http://bower.io>).
    This package provides a data type and ToJSON/FromJSON instances for Bower'\''s
    package manifest file, bower.json.

category:             Web
abi:                  97753baca187cda459c243e94dcca03d
exposed:              True
exposed-modules:      Web.Bower.PackageMeta
hidden-modules:       Web.Bower.PackageMeta.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/bower-json-1.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/bower-json-1.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/bower-json-1.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bower-json
hs-libraries:         HSbower-json-1.1.0.0-Jcups7R7Jws2U7K0pAgSfs
depends:
    aeson-2.1.2.1-DzmMfEZgdOFRIaYChwLwW
    aeson-better-errors-0.9.1.2-BOMq2gR87zF1uF2DvrnLzu base-4.17.2.1
    bytestring-0.11.5.3 deepseq-1.4.8.0 ghc-prim-0.9.1 mtl-2.2.2
    scientific-0.3.7.0-I6iMwi20J4G9Jw2tSdEPEK text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-3jxCiK1Dn5HHqgJhQ3B9SH
    vector-0.13.2.0-KDCTRjRQ0urK2B6TNAGAn8

haddock-interfaces:   /usr/share/doc/haskell-bower-json/html/bower-json.haddock
haddock-html:         /usr/share/doc/haskell-bower-json/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
